@@ -128,7 +128,6 @@ $body$
         passhash  text,
         salt      text,
         remark    text,
-        stamp     json,
         CONSTRAINT kosher_nick CHECK (nick ~* '^[[:alnum:]_][[:alnum:]_-]+$')
       )/,
 
@@ -249,8 +248,7 @@ $body$#,
         scode      varchar(32) UNIQUE,
         schedule   text UNIQUE NOT NULL,
         disabled   boolean NOT NULL,
-        remark     text,
-        stamp      json
+        remark     text
     )
     #,
 
@@ -291,7 +289,6 @@ $body$#,
         sid        integer REFERENCES schedules (sid) NOT NULL,
         effective  timestamptz NOT NULL,
         remark     text,
-        stamp      json,
         UNIQUE (eid, effective)
       )/,
 
@@ -317,7 +314,6 @@ $body$#,
         priv       privilege NOT NULL,
         effective  timestamptz NOT NULL,
         remark     text,
-        stamp      json,
         UNIQUE (eid, effective)
     )/,
 
@@ -379,8 +375,8 @@ $body$#,
           FETCH FIRST ROW ONLY
       $$ LANGUAGE sql IMMUTABLE#,
 
-    q#-- this function will return 'jsonb' after PostgreSQL 9.4 comes out!!!
-      CREATE OR REPLACE FUNCTION schedule_at_timestamp (INTEGER, TIMESTAMP WITH TIME ZONE)
+    q#-- function to get SID for an employee as of timestamp
+      CREATE OR REPLACE FUNCTION sid_at_timestamp (INTEGER, TIMESTAMP WITH TIME ZONE)
       RETURNS integer AS $$
           SELECT sid FROM (
               SELECT NULL AS sid, '4713-01-01 BC' AS effective
@@ -395,6 +391,90 @@ $body$#,
           FETCH FIRST ROW ONLY
       $$ LANGUAGE sql IMMUTABLE#,
 
+    q#-- function to get the privhistory record applicable to an employee
+      -- as of a timestamp
+      CREATE OR REPLACE FUNCTION privhistory_at_timestamp (
+          IN INTEGER, 
+          IN TIMESTAMP WITH TIME ZONE,
+          OUT phid INTEGER, 
+          OUT eid INTEGER, 
+          OUT priv PRIVILEGE, 
+          OUT effective TIMESTAMP WITH TIME ZONE, 
+          OUT remark TEXT 
+      )
+      AS $$
+          SELECT phid, eid, priv, effective, remark FROM privhistory 
+          WHERE eid=$1 AND effective <= $2
+          ORDER BY effective DESC
+          FETCH FIRST ROW ONLY
+      $$ LANGUAGE sql#,
+
+    q#-- function to get the privhistory record applicable to an employee
+      -- as of the beginning of a tsrange
+      CREATE OR REPLACE FUNCTION privhistory_at_tsrange (
+          IN INTEGER, 
+          IN TSTZRANGE,
+          OUT phid INTEGER, 
+          OUT eid INTEGER, 
+          OUT priv PRIVILEGE, 
+          OUT effective TIMESTAMP WITH TIME ZONE, 
+          OUT remark TEXT 
+      )
+      AS $$
+          SELECT phid, eid, priv, effective, remark
+          FROM privhistory_at_timestamp( $1, lower( $2 ) )
+      $$ LANGUAGE sql#,
+
+    q#-- function to get schedhistory record applicable to an employee 
+      -- as of a timestamp
+      CREATE OR REPLACE FUNCTION schedhistory_at_timestamp (
+          IN INTEGER, 
+          IN TIMESTAMP WITH TIME ZONE,
+          OUT shid INTEGER, 
+          OUT eid INTEGER, 
+          OUT sid INTEGER, 
+          OUT effective TIMESTAMP WITH TIME ZONE, 
+          OUT remark TEXT 
+      )
+      AS $$
+          SELECT shid, eid, sid, effective, remark FROM schedhistory 
+          WHERE eid=$1 AND effective <= $2
+          ORDER BY effective DESC
+          FETCH FIRST ROW ONLY
+      $$ LANGUAGE sql#,
+
+    q#-- function to get the schedhistory record applicable to an employee
+      -- as of the beginning of a tsrange
+      CREATE OR REPLACE FUNCTION schedhistory_at_tsrange (
+          IN INTEGER, 
+          IN TSTZRANGE,
+          OUT shid INTEGER, 
+          OUT eid INTEGER, 
+          OUT sid INTEGER, 
+          OUT effective TIMESTAMP WITH TIME ZONE, 
+          OUT remark TEXT 
+      )
+      AS $$
+          SELECT shid, eid, sid, effective, remark
+          FROM schedhistory_at_timestamp( $1, lower( $2 ) )
+      $$ LANGUAGE sql#,
+
+    q#-- given an EID and a tstzrange, IF a single privlevel applies throughout
+      -- the entire range, returns that privlevel, otherwise NULL
+      CREATE OR REPLACE FUNCTION priv_change_during_range(INTEGER, TSTZRANGE)
+      RETURNS boolean AS $$
+          SELECT $2::tstzrange @> effective AS priv_change_during_range 
+              FROM privhistory WHERE eid=$1;
+      $$ LANGUAGE sql IMMUTABLE#,
+
+    q#-- given an EID and a tstzrange, IF a single SID applies throughout
+      -- the entire range, returns that SID, otherwise NULL
+      CREATE OR REPLACE FUNCTION schedule_change_during_range(INTEGER, TSTZRANGE)
+      RETURNS boolean AS $$
+          SELECT $2::tstzrange @> effective AS schedule_change_during_range 
+              FROM schedhistory WHERE eid=$1;
+      $$ LANGUAGE sql IMMUTABLE#,
+
     q#-- wrapper function to get priv as of current timestamp
       CREATE OR REPLACE FUNCTION current_priv (INTEGER)
       RETURNS privilege AS $$
@@ -405,7 +485,7 @@ $body$#,
       -- this function will return 'jsonb' after PostgreSQL 9.4 comes out!!!
       CREATE OR REPLACE FUNCTION current_schedule (INTEGER)
       RETURNS integer AS $$
-          SELECT schedule_at_timestamp($1, current_timestamp)
+          SELECT sid_at_timestamp($1, current_timestamp)
       $$ LANGUAGE sql IMMUTABLE#,
 
     q/-- activities
@@ -511,13 +591,13 @@ $body$#,
       -- the entire interval
     CREATE OR REPLACE FUNCTION schedule_policy() RETURNS trigger AS $$
         DECLARE
-            sched text;
+            test_sid text;
             sh_count integer;
         BEGIN
             -- the EID is NEW.eid, interval is NEW.intvl
             -- 1. is there a schedule at the beginning of the interval?
-            SELECT schedule_at_timestamp(NEW.eid, lower(NEW.intvl)) INTO sched;
-            IF sched IS NULL THEN
+            SELECT sid_at_timestamp(NEW.eid, lower(NEW.intvl)) INTO test_sid;
+            IF test_sid IS NULL THEN
                 RAISE EXCEPTION 'employee schedule for this interval cannot be determined';
             END IF;
             -- 2. are there any schedhistory records during the interval?
