@@ -60,7 +60,7 @@ set( 'SQL_EMPLOYEE_PRIV_AT_TIMESTAMP', q/
 
 #
 set( 'SQL_EMPLOYEE_SCHEDULE_AT_TIMESTAMP', q/
-      SELECT schedule_at_timestamp($1, $2)
+      SELECT sid_at_timestamp($1, $2)
       / );
 
 # 
@@ -105,6 +105,35 @@ set( 'SQL_EMPLOYEE_COUNT_BY_PRIV_LEVEL', q/
       ) SELECT count(*) FROM emps_with_privs WHERE priv=?
       / );
 
+#
+set( 'SQL_EMPLOYEE_PRIV_CHANGE_DURING_RANGE', q/
+     SELECT priv_change_during_range( ?, ? )
+     / );
+
+#
+set( 'SQL_EMPLOYEE_PRIVHISTORY_AT_TIMESTAMP', q/
+     SELECT phid, eid, priv, effective, remark FROM privhistory_at_timestamp( ?, ? )
+     / );
+
+#
+set( 'SQL_EMPLOYEE_PRIVHISTORY_AT_TSRANGE', q/
+     SELECT phid, eid, priv, effective, remark FROM privhistory_at_tsrange( ?, ? )
+     / );
+
+#
+set( 'SQL_EMPLOYEE_SCHEDULE_CHANGE_DURING_RANGE', q/
+     SELECT schedule_change_during_range( ?, ? )
+     / );
+
+#
+set( 'SQL_EMPLOYEE_SCHEDHISTORY_AT_TIMESTAMP', q/
+     SELECT shid, eid, sid, effective, remark FROM schedhistory_at_timestamp( ?, ? )
+     / );
+
+#
+set( 'SQL_EMPLOYEE_SCHEDHISTORY_AT_TSRANGE', q/
+     SELECT shid, eid, sid, effective, remark FROM schedhistory_at_tsrange( ?, ? )
+     / );
 
 # -----------------------------------
 # DO NOT EDIT ANYTHING BELOW THIS LINE
