@@ -55,11 +55,11 @@ App::Dochazka::REST::Dispatch::ACL - ACL module
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -169,8 +169,8 @@ sub check_acl_context {
 
 =head2 acl_check_is_me
 
-Takes a property and a value. The property can be either 'eid' or 'nick'.
-This routine checks the eid/nick against C<< $self->context->{'current_obj'} >>
+Takes a property and a value. The property can be 'eid', 'nick', or 'sec_id'.
+This routine checks the eid/nick/sec_id against C<< $self->context->{'current_obj'} >>
 (the current employee object) and returns a boolean value answering the
 question "is this me?"
 
