@@ -50,10 +50,15 @@ use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
 use App::Dochazka::REST::Model::Schedhistory qw( get_schedhistory );
 use App::Dochazka::REST::Model::Schedintvls;
 use App::Dochazka::REST::Model::Schedule qw( get_all_schedules );
-use App::Dochazka::REST::Model::Shared qw( load_multiple priv_by_eid schedule_by_eid );
+use App::Dochazka::REST::Model::Shared qw( 
+    canonicalize_tsrange 
+    load_multiple 
+    priv_by_eid 
+    schedule_by_eid 
+);
 use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
-#use App::Dochazka::REST::Util qw( hash_the_password pre_update_comparison );
+use App::Dochazka::REST::Util::Schedule qw( intervals_in_schedule );
 use App::Dochazka::REST::Util::Timestamp qw( $current_year $current_month );
 use Data::Dumper;
 use Module::Runtime qw( use_module );
@@ -77,11 +82,11 @@ App::Dochazka::REST::Dispatch - Implementation of top-level resources
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 =head1 DESCRIPTION
@@ -1205,6 +1210,7 @@ sub handler_history_post {
             eid => $emp->eid, 
             effective => $entity->{'effective'},
             $prop => $entity->{$prop},
+            remark => $entity->{'remark'},
         );
     } catch {
         $log->crit($_);
@@ -1365,27 +1371,7 @@ sub handler_get_interval_eid {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_eid " ); 
 
-    my $context = $self->context;
-
-    # first pass
-    if ( $pass == 1 ) {
-        my $status = App::Dochazka::REST::Model::Interval::fetch_by_eid_and_tsrange(
-            $context->{'dbix_conn'},
-            $context->{'mapping'}->{'eid'}, 
-            $context->{'mapping'}->{'tsrange'} 
-        );
-        if ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
-            $self->mrest_declare_status( explanation => 'DISPATCH_NOTHING_IN_TSRANGE',
-                args => [ 'attendance intervals' ] 
-            );
-            return 0;
-        }
-        $context->{'stashed_attendance_status'} = $status;
-        return 1;
-    }
-
-    # second pass
-    return $context->{'stashed_attendance_status'};
+    return $self->_handler_get_interval( 'eid', $pass );
 }
 
 
@@ -1401,29 +1387,7 @@ sub handler_get_interval_nick {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_nick " ); 
 
-    my $context = $self->context;
-
-    # first pass
-    if ( $pass == 1 ) {
-        my $emp = shared_first_pass_lookup( $self, 'nick', $self->context->{'mapping'}->{'nick'} );
-        return 0 unless $emp;
-        my $status = App::Dochazka::REST::Model::Interval::fetch_by_eid_and_tsrange(
-            $context->{'dbix_conn'},
-            $emp->eid,
-            $context->{'mapping'}->{'tsrange'} 
-        );
-        if ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
-            $self->mrest_declare_status( explanation => 'DISPATCH_NOTHING_IN_TSRANGE',
-                args => [ 'attendance intervals' ] 
-            );
-            return 0;
-        }
-        $context->{'stashed_attendance_status'} = $status;
-        return 1;
-    }
-
-    # second pass
-    return $context->{'stashed_attendance_status'};
+    return $self->_handler_get_interval( 'nick', $pass );
 }
 
 
@@ -1439,13 +1403,33 @@ sub handler_get_interval_self {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_self " ); 
 
+    return $self->_handler_get_interval( 'self', $pass );
+}
+
+
+sub _handler_get_interval {
+    my ( $self, $key, $pass ) = @_;
+
     my $context = $self->context;
 
     # first pass
     if ( $pass == 1 ) {
+        my $value;
+        if ( $key eq 'self' ) {
+            $key = 'eid';
+            $value = $context->{'current'}->{'eid'};
+        } else {
+            $value = $context->{'mapping'}->{ $key };
+        }
+        if ( ! acl_check_is_me( $self, $key => $value ) ) {
+            $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+            return 0;
+        }
+        my $emp = shared_first_pass_lookup( $self, $key, $value );
+        return 0 unless $emp;
         my $status = App::Dochazka::REST::Model::Interval::fetch_by_eid_and_tsrange(
             $context->{'dbix_conn'},
-            $context->{'current'}->{'eid'}, 
+            $emp->eid,
             $context->{'mapping'}->{'tsrange'} 
         );
         if ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
@@ -1959,6 +1943,119 @@ sub handler_get_schedule_eid {
 }
 
 
+=head3 handler_get_interval_fillup_eid
+
+=cut
+
+sub handler_get_interval_fillup_eid {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ .  "::handler_get_interval_fillup_eid" ); 
+
+    return _handler_get_interval_fillup( $self, 'eid', $pass );
+}
+
+=head3 handler_get_interval_fillup_nick
+
+=cut
+
+sub handler_get_interval_fillup_nick {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ .  "::handler_get_interval_fillup_nick" ); 
+
+    return _handler_get_interval_fillup( $self, 'nick', $pass );
+}
+
+=head3 handler_get_interval_fillup_self
+
+=cut
+
+sub handler_get_interval_fillup_self {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ .  "::handler_get_interval_fillup_self" ); 
+    return _handler_get_interval_fillup( $self, 'self', $pass );
+}
+
+sub _handler_get_interval_fillup {
+    my ( $self, $key, $pass ) = @_;
+
+    my $context = $self->context;
+
+    # first pass
+    if ( $pass == 1 ) {
+        my $value;
+        if ( $key eq 'self' ) {
+            $key = 'eid';
+            $value = $context->{'current'}->{'eid'};
+        } else {
+            $value = $context->{'mapping'}->{ $key };
+        }
+        if ( ! acl_check_is_me( $self, $key => $value ) ) {
+            $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+            return 0;
+        }
+        my $emp = shared_first_pass_lookup( $self, $key, $value );
+        return 0 unless $emp;
+
+        # get and validate tsrange entered by the user
+        my $lower = $context->{'mapping'}->{'lower'};
+        my $upper = $context->{'mapping'}->{'upper'};
+        my $dbix_conn = $context->{'dbix_conn'};
+        my $status = canonicalize_tsrange( $dbix_conn, "( $lower 00:00, $upper 23:59 )" );
+        if( $status->not_ok ) {
+            $status->{'http_code'} = 400;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+        my $tsr = $status->payload;
+
+        # check for priv and schedule changes during the tsrange
+        if ( $emp->priv_change_during_range( $dbix_conn, $tsr ) ) {
+            $status = $CELL->status_err( 'DOCHAZKA_EMPLOYEE_PRIV_CHANGED'); 
+            $status->{'http_code'} = 500;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+        if ( $emp->schedule_change_during_range( $dbix_conn, $tsr ) ) {
+            $status = $CELL->status_err( 'DOCHAZKA_EMPLOYEE_SCHEDULE_CHANGED'); 
+            $status->{'http_code'} = 500;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+
+        # We have the employee in $emp and tsrange in $tsr, now get the 
+        # prevailing schedule for that employee in that range
+        my $shobj = $emp->schedhistory_at_timestamp( $dbix_conn, $tsr );
+        unless ( $shobj->sid ) {
+            $status = $CELL->status_err( 'DISPATCH_EMPLOYEE_NO_SCHEDULE' );
+            $status->{'http_code'} = 500;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+        my $sched_obj = App::Dochazka::REST::Model::Schedule->load_by_sid(
+            $dbix_conn,
+            $shobj->sid
+        )->payload;
+        die "AGAH!" unless ref( $sched_obj) eq 'App::Dochazka::REST::Model::Schedule'
+            and $sched_obj->schedule =~ m/high_dow/;
+
+        $status = intervals_in_schedule( $sched_obj->schedule, $tsr );
+        if ( $status->not_ok ) {
+            $status->{'http_code'} = 400;
+            $self->mrest_declare_status( $status );
+            return 0;
+        }
+        $self->context->{'stashed_schedule_intervals'} = $status->payload;
+        return 1;
+    }
+    
+    # second pass
+    return $CELL->status_ok( 
+        'DISPATCH_SCHEDULE_INTERVALS_FOUND',
+        payload => $self->context->{'stashed_schedule_intervals'},
+    );
+}
+
+
 =head3 handler_get_schedule_nick
 
 =cut
@@ -2026,7 +2123,7 @@ sub handler_schedule_new {
         $self->mrest_declare_status( code => 500, explanation => $status->text );
         return $fail;
     }
-    $log->info( "schedule/intervals: Scratch intervals inserted" );
+    $log->info( "schedule/new: Scratch intervals inserted" );
 
     #
     # convert the intervals to get the 'schedule' property
@@ -2036,7 +2133,7 @@ sub handler_schedule_new {
         $self->mrest_declare_status( code => 400, explanation => $status->text );
         return $fail;
     }
-    $log->info( "schedule/intervals: Scratch intervals converted" );
+    $log->info( "schedule/new: Scratch intervals converted" );
 
     #
     # spawn Schedule object
@@ -2068,7 +2165,7 @@ sub handler_schedule_new {
         }
     } else {
         $self->mrest_declare_status( code => 500, explanation => 
-            "schedule/intervals: Model/Schedule.pm->insert failed: " . $status->text );
+            "schedule/new: Model/Schedule.pm->insert failed: " . $status->text );
         $intvls->delete( $context->{'dbix_conn'} );
         return $fail;
     }
@@ -2079,7 +2176,7 @@ sub handler_schedule_new {
         $self->mrest_declare_status( code => 500, explanation => "Could not delete schedintvls: " . $status->text );
         return $fail;
     }
-    $log->info( "schedule/intervals: scratch intervals deleted" );
+    $log->info( "schedule/new: scratch intervals deleted" );
     #
     # success
     return $CELL->status_ok( $code, payload => $sched->TO_JSON );
