@@ -63,11 +63,11 @@ App::Dochazka::REST::Model::Employee - Employee data model
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -442,6 +442,139 @@ sub load_by_sec_id {
 }
 
 
+=head2 priv_change_during_range
+
+Given a DBIx::Connector object and a tsrange, returns the employee's privlevel
+during that range, or NULL if the privlevel changed during the range.
+
+=cut
+
+sub priv_change_during_range {
+    my $self = shift;
+    my ( $conn, $tsr ) = validate_pos( @_, 
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::priv_change_during_range with argument $tsr" );
+
+    my ( $boolean_result ) = @{ select_single( 
+        conn => $conn, 
+        sql => $site->SQL_EMPLOYEE_PRIV_CHANGE_DURING_RANGE, 
+        keys => [ $self->eid, $tsr ], 
+    )->payload };
+
+    return $boolean_result;
+}
+
+
+=head2 privhistory_at_timestamp
+
+Given a DBIx::Connector object and a string that can be either a timestamp
+or a tsrange, returns an L<App::Dochazka::REST::Model::Privhistory> object
+containing the privhistory record applicable to the employee either at the
+timestamp or at the lower bound of the tsrange. If there is no such record,
+the object's properties will be undefined.
+
+=cut
+
+sub privhistory_at_timestamp {
+    my $self = shift;
+    my ( $conn, $arg ) = validate_pos( @_, 
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::privhistory_at_timestamp with argument $arg" );
+
+    # if it looks like a tsrange, use tsrange, otherwise use timestamp
+    my $sql = ( $arg =~ m/[[(].*,.*[])]/ )
+        ? $site->SQL_EMPLOYEE_PRIVHISTORY_AT_TSRANGE
+        : $site->SQL_EMPLOYEE_PRIVHISTORY_AT_TIMESTAMP;
+
+    my $array = select_single( 
+        conn => $conn, 
+        sql => $sql,
+        keys => [ $self->eid, $arg ], 
+    )->payload;
+
+    $log->debug( 'privhistory_at_timestamp: database said: ' . Dumper( $array ) );
+
+    return App::Dochazka::REST::Model::Privhistory->spawn(
+        phid => $array->[0],
+        eid  => $array->[1],
+        priv  => $array->[2],
+        effective  => $array->[3],
+        remark  => $array->[4],
+    );
+}
+
+
+=head2 schedule_change_during_range
+
+Given a DBIx::Connector object and a tsrange, returns true or false value
+reflecting whether or not the employee's schedule changed during
+the range.
+
+=cut
+
+sub schedule_change_during_range {
+    my $self = shift;
+    my ( $conn, $tsr ) = validate_pos( @_, 
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::schedule_change_during_range with argument $tsr" );
+
+    my ( $boolean_result ) = @{ select_single( 
+        conn => $conn, 
+        sql => $site->SQL_EMPLOYEE_SCHEDULE_CHANGE_DURING_RANGE,
+        keys => [ $self->eid, $tsr ], 
+    )->payload };
+
+    return $boolean_result;
+}
+
+
+=head2 schedhistory_at_timestamp
+
+Given a DBIx::Connector object and a string that can be either a timestamp
+or a tsrange, returns an L<App::Dochazka::REST::Model::Schedhistory> object
+containing the history record applicable to the employee either at the
+timestamp or at the lower bound of the tsrange. If there is no such record,
+the object's properties will be undefined.
+
+=cut
+
+sub schedhistory_at_timestamp {
+    my $self = shift;
+    my ( $conn, $arg ) = validate_pos( @_, 
+        { isa => 'DBIx::Connector' },
+        { type => SCALAR },
+    );
+    $log->debug( "Entering " . __PACKAGE__ . "::schedhistory_at_timestamp with argument $arg" );
+
+    # if it looks like a tsrange, use tsrange, otherwise use timestamp
+    my $sql = ( $arg =~ m/[[(].*,.*[])]/ )
+        ? $site->SQL_EMPLOYEE_SCHEDHISTORY_AT_TSRANGE
+        : $site->SQL_EMPLOYEE_SCHEDHISTORY_AT_TIMESTAMP;
+
+    my $array = select_single( 
+        conn => $conn, 
+        sql => $sql,
+        keys => [ $self->eid, $arg ], 
+    )->payload;
+
+    $log->debug( 'schedhistory_at_timestamp: database said: ' . Dumper( $array ) );
+
+    return App::Dochazka::REST::Model::Schedhistory->spawn(
+        shid => $array->[0],
+        eid  => $array->[1],
+        sid  => $array->[2],
+        effective  => $array->[3],
+        remark  => $array->[4],
+    );
+}
+
+
 
 =head1 FUNCTIONS
 
