@@ -37,7 +37,7 @@ use strict;
 use warnings FATAL => 'all';
 use App::CELL qw( $CELL $log $meta $site );
 use Data::Dumper;
-use App::Dochazka::REST::Model::Shared qw( cud load load_multiple );
+use App::Dochazka::REST::Model::Shared qw( canonicalize_tsrange cud load load_multiple );
 use Params::Validate qw( :all );
 
 # we get 'spawn', 'reset', and accessors from parent
@@ -54,11 +54,11 @@ App::Dochazka::REST::Model::Interval - activity intervals data model
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -259,18 +259,44 @@ BEGIN {
 
 =head2 fetch_by_eid_and_tsrange
 
-Boilerplate.
+Given an EID and a tsrange, return all that employee's intervals that 
+fall within that tsrange.
+
+Before any records are returned, the tsrange is checked to see if it
+overlaps with any privlevel or schedule changes - in which case an error is
+returned.  This is so interval report-generators do not have to handle
+changes in employee status.
 
 =cut
 
 sub fetch_by_eid_and_tsrange {
     my ( $conn, $eid, $tsrange ) = @_;
 
+    my $status = canonicalize_tsrange( $conn, $tsrange );
+    return $status unless $status->ok;
+
+    $status = App::Dochazka::REST::Model::Employee->load_by_eid( $conn, $eid );
+    return $status unless $status->ok;
+    my $emp = $status->payload;
+    die "AAGHA!" unless $emp->eid == $eid;
+
+    # check for priv change during tsrange
+    my $priv_change = $emp->priv_change_during_range( $conn, $tsrange );
+    $log->debug( "fetch_by_eid_and_tsrange: priv_change_during_range returned " . Dumper( $priv_change ) );
+    if ( $priv_change ) {
+        return $CELL->status_err( 'DOCHAZKA_EMPLOYEE_PRIV_CHANGED' );
+    }
+    my $schedule_change = $emp->schedule_change_during_range( $conn, $tsrange );
+    $log->debug( "fetch_by_eid_and_tsrange: schedule_change_during_range returned " . Dumper($schedule_change ) );
+    if ( $schedule_change ) {
+        return $CELL->status_err( 'DOCHAZKA_EMPLOYEE_SCHEDULE_CHANGED' );
+    }
+
     return load_multiple(
         conn => $conn,
         class => __PACKAGE__,
         sql => $site->SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE,
-        keys => [ $eid, $tsrange ],
+        keys => [ $eid, $tsrange, $site->DOCHAZKA_INTERVAL_SELECT_LIMIT ],
     );
 }
 
