@@ -54,11 +54,11 @@ the data model
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -78,28 +78,59 @@ This module provides the following exports:
 
 =over 
 
-=item * C<cud> (Create, Update, Delete -- for single-record statements only)
+=item * C<canonicalize_ts>
 
-=item * C<decode_schedule_json> function (given JSON string, return corresponding hashref)
+Run timestamp by PostgreSQL
 
-=item * C<load> (Load/Fetch/Retrieve a single datamodel object)
+=item * C<canonicalize_tsrange>
 
-=item * C<load_multiple> (Load/Fetch/Retrieve multiple datamodel objects)
+Run tsrange by PostgreSQL
 
-=item * C<noof> (get total number of records in a data model table)
+=item * C<cud>
+
+Create, Update, Delete -- for single-record statements only
+
+=item * C<decode_schedule_json> 
+
+Given JSON string, return corresponding hashref
+
+=item * C<load> 
+
+Load/Fetch/Retrieve a single datamodel object
+
+=item * C<load_multiple> 
+
+Load/Fetch/Retrieve multiple datamodel objects
+
+=item * C<noof> 
+
+Get total number of records in a data model table
 
 =item * C<priv_by_eid> 
 
 =item * C<schedule_by_eid>
 
-=item * C<select_single> (run an arbitrary SELECT that returns 0 or 1 records)
+=item * C<select_single> 
+
+Run an arbitrary SELECT that returns 0 or 1 records
 
 =back
 
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( cud decode_schedule_json load load_multiple noof priv_by_eid schedule_by_eid select_single );
+our @EXPORT_OK = qw( 
+    canonicalize_ts
+    canonicalize_tsrange
+    cud 
+    decode_schedule_json 
+    load 
+    load_multiple 
+    noof 
+    priv_by_eid 
+    schedule_by_eid 
+    select_single 
+);
 
 
 
@@ -107,6 +138,58 @@ our @EXPORT_OK = qw( cud decode_schedule_json load load_multiple noof priv_by_ei
 =head1 FUNCTIONS
 
 
+=head2 canonicalize_ts
+
+Given a string that might be a timestamp, "canonicalize" it by running it
+through the database in the SQL statement:
+
+    SELECT CAST( ? AS timestamptz )
+
+=cut
+
+sub canonicalize_ts {
+    my ( $conn, $ts ) = @_;
+
+    my $status = select_single(
+        conn => $conn,
+        sql => 'SELECT CAST( ? AS timestamptz )',
+        keys => [ $ts ],
+    );
+    _replace_payload_array_with_string( $status ) if $status->ok;
+    return $status;    
+}
+
+sub _replace_payload_array_with_string {
+    my $status = shift;
+    $status->payload( $status->payload->[0] );
+    return $status;
+}
+
+=head2 canonicalize_tsrange
+
+Given a string that might be a tsrange, "canonicalize" it by running it
+through the database in the SQL statement:
+
+    SELECT CAST( ? AS tstzrange )
+
+Returns an L<App::CELL::Status> object. If the status code is OK, then the
+tsrange is OK and its canonicalized form is in the paylmad. Otherwise, some
+kind of error occurred, as described in the status object.
+
+=cut
+
+sub canonicalize_tsrange {
+    my ( $conn, $tsr ) = @_;
+
+    my $status = select_single(
+        conn => $conn,
+        sql => 'SELECT CAST( ? AS tstzrange)',
+        keys => [ $tsr ],
+    );
+    _replace_payload_array_with_string( $status ) if $status->ok;
+    return $status;    
+}
+
 
 =head2 make_test_exists
 
