@@ -54,11 +54,14 @@ App::Dochazka::REST::ResourceDefs - Resource definitions
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
+my $tsrange_validation = qr/^[[(].*,.*[])]$/;
+my $term_validation = qr/^[[:alnum:]_][[:alnum:]_-]*$/;
+my $date_validation = qr/^\d{2,4}-\d{1,2}-\d{1,2}$/;
 
 
 
@@ -797,7 +800,7 @@ EOH
         },
         cli => 'employee nick $NICK [$JSON]',
         validations => {
-            'nick' => qr/^[%[:alnum:]_][%[:alnum:]_-]*$/,
+            'nick' => $term_validation,
         },
         description => "Retrieves (GET), updates/inserts (PUT), and/or deletes (DELETE) the employee specified by the ':nick' parameter",
         documentation => <<'EOH',
@@ -862,6 +865,9 @@ EOH
         acl_profile => 'admin',
         cli => 'employee search nick $KEY',
         description => 'Search employee profiles on nick (% is wild)',
+        validations => {
+            'key' => qr/^[%[:alnum:]_][%[:alnum:]_-]*$/,
+        },
         documentation => <<'EOH',
 =pod
 
@@ -1114,7 +1120,7 @@ EOH
         description => 'Get a slice of history of privilege level changes for employee with the given EID',
         validations => {
             'eid' => 'Int',
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         documentation => <<'EOH',
 =pod
@@ -1135,7 +1141,7 @@ EOH
         description => 'Get a slice of history of schedule changes for employee with the given EID',
         validations => {
             'eid' => 'Int',
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         documentation => <<'EOH',
 =pod
@@ -1158,7 +1164,7 @@ EOH
         },
         cli => 'priv history nick $NICK [$JSON]',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
+            'nick' => $term_validation,
         },
         description => 'Retrieves entire history of privilege level changes for employee with the given nick (GET); or, with an appropriate content body, adds (PUT) a record to employee\'s privhistory',
         documentation => <<'EOH',
@@ -1206,7 +1212,7 @@ EOH
         },
         cli => 'schedule history nick $NICK [$JSON]',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
+            'nick' => $term_validation,
         },
         description => 'Retrieves entire history of schedule changes for employee with the given nick (GET); or, with an appropriate content body, adds (PUT) a record to employee\'s schedule history',
         documentation => <<'EOH',
@@ -1249,8 +1255,8 @@ EOH
         acl_profile => 'inactive',
         cli => 'priv history nick $NICK $TSRANGE',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'nick' => $term_validation,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Get partial history of privilege level changes for employee with the given nick ' . 
                      '(i.e, limit to given tsrange)',
@@ -1271,8 +1277,8 @@ EOH
         acl_profile => 'inactive',
         cli => 'schedule history nick $NICK $TSRANGE',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'nick' => $term_validation,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Get partial history of schedule changes for employee with the given nick ' . 
                      '(i.e, limit to given tsrange)',
@@ -1377,7 +1383,7 @@ EOH
         acl_profile => 'inactive',
         cli => 'priv history self [$TSRANGE]',
         validations => {
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieves privhistory of present employee, with option to limit to :tsrange',
         documentation => <<'EOH',
@@ -1401,7 +1407,7 @@ EOH
         acl_profile => 'inactive',
         cli => 'schedule history self [$TSRANGE]',
         validations => {
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieves schedule history of present employee, with option to limit to :tsrange',
         documentation => <<'EOH',
@@ -1447,21 +1453,130 @@ EOH
         handler => {
             GET => 'handler_get_interval_eid',
         },
-        acl_profile => 'admin', 
+        acl_profile => 'active', 
         cli => 'interval eid $EID $TSRANGE',
         validations => {
             'eid' => 'Int',
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve an arbitrary employee\'s intervals over the given tsrange',
         documentation => <<'EOH',
 =pod
 
 With this resource, administrators can retrieve any employee's intervals 
-over a given tsrange. 
+over a given tsrange, and active employees can do the same with their own intervals. 
 
-There are no syntactical limitations on the tsrange, but if too many records would
-be fetched, the return status will be C<DISPATCH_TOO_MANY_RECORDS_FOUND>.
+Before any records are returned, the tsrange is checked to see if it overlaps with
+any privlevel or schedule changes - in which case an error is returned. This is so
+interval report-generators do not have to handle changes in employee status.
+
+By default, the number of intervals returned is limited to 500. This number
+can be changed via the DOCHAZKA_INTERVAL_SELECT_LIMIT site configuration
+parameter (set to 'undef' for no limit).
+EOH
+    },
+
+    # /interval/fillup
+    'interval/fillup' =>
+    {
+        parent => '/',
+        handler => 'handler_noop',
+        acl_profile => 'passerby',
+        cli => 'interval',
+        description => 'Parent for interval fillup resources',
+        documentation => <<'EOH',
+=pod
+
+Parent for interval fillup resources
+EOH
+    },
+
+    # /interval/fillup/eid/:eid/:lower/:upper
+    '/interval/fillup/eid/:eid/:lower/:upper' => 
+    {
+        parent => 'interval/fillup',
+        handler => {
+            GET => 'handler_get_interval_fillup_eid',
+        },
+        acl_profile => 'active', 
+        cli => 'interval fillup eid $EID $TIMESTAMP',
+        validations => {
+            'eid' => 'Int',
+            'lower' => $date_validation,
+            'upper' => $date_validation,
+        },
+        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
+        documentation => <<'EOH',
+=pod
+
+=over
+
+=item * GET
+
+Return set of scheduled attendance intervals (tsranges) for the given employee
+over the given tsrange.  The result set includes only those scheduled intervals
+that fall _fully_ within the given tsrange.
+
+=back
+EOH
+    },
+
+    # /interval/fillup/nick/:nick/:lower/:upper
+    '/interval/fillup/nick/:nick/:lower/:upper' => 
+    {
+        parent => 'interval/fillup',
+        handler => {
+            GET => 'handler_get_interval_fillup_nick',
+        },
+        acl_profile => 'active', 
+        cli => 'schedule intervals nick $NICK $TIMESTAMP',
+        validations => {
+            'nick' => $term_validation,
+            'lower' => $date_validation,
+            'upper' => $date_validation,
+        },
+        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
+        documentation => <<'EOH',
+=pod
+
+=over
+
+=item * GET
+
+Return set of scheduled attendance intervals (tsranges) for the given employee
+over the given tsrange.  The result set includes only those scheduled intervals
+that fall _fully_ within the given tsrange.
+
+=back
+EOH
+    },
+
+    # /interval/fillup/self/:lower/:upper
+    '/interval/fillup/self/:lower/:upper' => 
+    {
+        parent => 'schedule',
+        handler => {
+            GET => 'handler_get_interval_fillup_self',
+        },
+        acl_profile => 'active', 
+        cli => 'schedule intervals self $TIMESTAMP',
+        description => 'Return set of scheduled attendance intervals (tsranges) for the given employee over the given tsrange',
+        validations => {
+            'lower' => $date_validation,
+            'upper' => $date_validation,
+        },
+        documentation => <<'EOH',
+=pod
+
+=over
+
+=item * GET
+
+Return set of scheduled attendance intervals (tsranges) for the given employee
+over the given tsrange.  The result set includes only those scheduled intervals
+that fall _fully_ within the given tsrange.
+
+=back
 EOH
     },
 
@@ -1563,21 +1678,26 @@ EOH
         handler => {
             GET => 'handler_get_interval_nick',
         },
-        acl_profile => 'admin', 
+        acl_profile => 'active', 
         cli => 'interval nick $NICK $TSRANGE',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'nick' => $term_validation,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve an arbitrary employee\'s intervals over the given tsrange',
         documentation => <<'EOH',
 =pod
 
 With this resource, administrators can retrieve any employee's intervals 
-over a given tsrange. 
+over a given tsrange, and active employees can do the same with their own intervals. 
 
-There are no syntactical limitations on the tsrange, but if too many records would
-be fetched, the return status will be C<DISPATCH_TOO_MANY_RECORDS_FOUND>.
+Before any records are returned, the tsrange is checked to see if it overlaps with
+any privlevel or schedule changes - in which case an error is returned. This is so
+interval report-generators do not have to handle changes in employee status.
+
+By default, the number of intervals returned is limited to 500. This number
+can be changed via the DOCHAZKA_INTERVAL_SELECT_LIMIT site configuration
+parameter (set to 'undef' for no limit).
 EOH
     },
 
@@ -1591,7 +1711,7 @@ EOH
         acl_profile => 'inactive', 
         cli => 'interval self $TSRANGE',
         validations => {
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve one\'s own intervals over the given tsrange',
         documentation => <<'EOH',
@@ -1600,8 +1720,13 @@ EOH
 With this resource, employees can retrieve their own attendance intervals 
 over a given tsrange. 
 
-There are no syntactical limitations on the tsrange, but if too many records would
-be fetched, the return status will be C<DISPATCH_TOO_MANY_RECORDS_FOUND>.
+Before any records are returned, the tsrange is checked to see if it overlaps with
+any privlevel or schedule changes - in which case an error is returned. This is so
+interval report-generators do not have to handle changes in employee status.
+
+By default, the number of intervals returned is limited to 500. This number
+can be changed via the DOCHAZKA_INTERVAL_SELECT_LIMIT site configuration
+parameter (set to 'undef' for no limit).
 EOH
     },
 
@@ -1672,7 +1797,7 @@ EOH
         cli => 'lock eid $EID $TSRANGE',
         validations => {
             'eid' => 'Int',
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve an arbitrary employee\'s locks over the given tsrange',
         documentation => <<'EOH',
@@ -1789,8 +1914,8 @@ EOH
         acl_profile => 'admin', 
         cli => 'lock nick $NICK $TSRANGE',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'nick' => $term_validation,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve an arbitrary employee\'s locks over the given tsrange',
         documentation => <<'EOH',
@@ -1814,7 +1939,7 @@ EOH
         acl_profile => 'inactive', 
         cli => 'lock self $TSRANGE',
         validations => {
-            'tsrange' => qr/^[[(].*,.*[])]$/,
+            'tsrange' => $tsrange_validation,
         },
         description => 'Retrieve one\'s own locks over the given tsrange',
         documentation => <<'EOH',
@@ -1885,7 +2010,7 @@ EOH
         acl_profile => 'admin', 
         cli => 'priv nick $NICK [$TIMESTAMP]',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
+            'nick' => $term_validation,
         },
         description => 'Get the present privlevel of arbitrary employee, or with optional timestamp, that employee\'s privlevel as of that timestamp',
         documentation => <<'EOH',
@@ -2073,7 +2198,7 @@ EOH
         acl_profile => 'admin', 
         cli => 'schedule nick $NICK [$TIMESTAMP]',
         validations => {
-            'nick' => qr/^[[:alnum:]_][[:alnum:]_-]*$/,
+            'nick' => $term_validation,
         },
         description => 'Get the current schedule of arbitrary employee, or with optional timestamp, that employee\'s schedule as of that timestamp',
         documentation => <<'EOH',
