@@ -67,11 +67,11 @@ App::Dochazka::REST::Dispatch::Shared - Shared dispatch functions
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 my $fail = $CELL->status_not_ok;
 
@@ -153,13 +153,13 @@ sub shared_first_pass_lookup {
     my $conn = $d_obj->context->{'dbix_conn'};
     my ( $status, $thing );
 
-    if ( $key eq 'AID' ) {
+    if ( uc($key) eq 'AID' ) {
         $thing = 'activity';
         $status = App::Dochazka::REST::Model::Activity->load_by_aid( $conn, $value );
     } elsif ( $key eq 'code' ) {
         $thing = 'activity';
         $status = App::Dochazka::REST::Model::Activity->load_by_code( $conn, $value );
-    } elsif ( $key eq 'EID' ) {
+    } elsif ( uc($key) eq 'EID' ) {
         $thing = 'employee';
         $status = App::Dochazka::REST::Model::Employee->load_by_eid( $conn, $value );
     } elsif ( $key eq 'nick' ) {
@@ -168,19 +168,19 @@ sub shared_first_pass_lookup {
     } elsif ( $key eq 'sec_id' ) {
         $thing = 'employee';
         $status = App::Dochazka::REST::Model::Employee->load_by_sec_id( $conn, $value );
-    } elsif ( $key eq 'IID' ) {
+    } elsif ( uc($key) eq 'IID' ) {
         $thing = 'interval';
         $status = App::Dochazka::REST::Model::Interval->load_by_iid( $conn, $value );
-    } elsif ( $key eq 'LID' ) {
+    } elsif ( uc($key) eq 'LID' ) {
         $thing = 'lock';
         $status = App::Dochazka::REST::Model::Lock->load_by_lid( $conn, $value );
-    } elsif ( $key eq 'PHID' ) {
+    } elsif ( uc($key) eq 'PHID' ) {
         $thing = 'privilege history record';
         $status = App::Dochazka::REST::Model::Privhistory->load_by_phid( $conn, $value );
-    } elsif ( $key eq 'SHID' ) {
+    } elsif ( uc($key) eq 'SHID' ) {
         $thing = 'schedule history record';
         $status = App::Dochazka::REST::Model::Schedhistory->load_by_shid( $conn, $value );
-    } elsif ( $key eq 'SID' ) {
+    } elsif ( uc($key) eq 'SID' ) {
         $thing = 'schedule';
         $status = App::Dochazka::REST::Model::Schedule->load_by_sid( $conn, $value );
     } elsif ( $key eq 'scode' ) {
@@ -497,6 +497,7 @@ sub shared_get_privsched {
     );
     my $emp = $d_obj->context->{'stashed_employee_object'};
     my $eid = $emp->eid;
+    my $nick = $emp->nick;
     my $ts = $d_obj->context->{'mapping'}->{'ts'};
     my $conn = $d_obj->context->{'dbix_conn'};
 
@@ -517,7 +518,7 @@ sub shared_get_privsched {
             if ( ! $return_value ) {
                 $d_obj->mrest_declare_status( 
                     code => 404, 
-                    explanation => "EID $eid has no $t assigned as of $ts" 
+                    explanation => "Employee $nick (EID $eid) has no $t assigned as of $ts" 
                 );
                 return $CELL->status_not_ok;
             }
@@ -535,7 +536,7 @@ sub shared_get_privsched {
             if ( ! $return_value ) {
                 $d_obj->mrest_declare_status( 
                     code => 404, 
-                    explanation => "EID $eid has no $t assigned"
+                    explanation => "Employee $nick (EID $eid) has no $t assigned"
                 );
                 return $CELL->status_not_ok;
             }
