@@ -67,11 +67,11 @@ App::Dochazka::REST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -232,18 +232,18 @@ sub req {
     }
 
     $r->authorization_basic( $user, $pass );
-
+    note( "About to send request $method $resource as $user " . ( $json ? "with $json" : "" ) );
     my $res = $test->request( $r );
     $code += 0;
     if ( $code != $res->code ) {
         diag( Dumper $res );
         BAIL_OUT(0);
     }
-    is( $res->code, $code, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 1" );
+    is( $res->code, $code, "Response code is $code" );
     my $content = $res->content;
     if ( $content ) {
         #diag( Dumper $content );
-        is_valid_json( $res->content, "$method $resource as $user " . ( $json ? "with $json" : "" ) . " 2" );
+        is_valid_json( $res->content, "Response entity is valid JSON" );
         my $status = status_from_json( $content );
         if ( my $location_header = $res->header( 'Location' ) ) {
             $status->{'location_header'} = $location_header;
@@ -536,11 +536,11 @@ sub create_testing_schedule {
     #
     # - request as root 
     my $status = req( $test, 201, 'root', 'POST', "schedule/new", $intvls_json );
-    is( $status->level, 'OK' );
+    is( $status->level, 'OK', 'POST schedule/new returned OK status' );
     is( $status->code, 'DISPATCH_SCHEDULE_INSERT_OK' );
     ok( exists $status->{'payload'} );
-    ok( exists $status->payload->{'sid'} );
-    ok( exists $status->payload->{'scode'} );
+    ok( exists $status->payload->{'sid'}, 'there is a SID' );
+    ok( exists $status->payload->{'scode'}, 'there is an scode' );
 
     return $status->payload->{'sid'};
 }
@@ -556,15 +556,18 @@ only argument.
 sub delete_testing_schedule {
     my ( $sid ) = @_;
 
+    note( "delete testing schedule (SID $sid)" );
+
     my $status = App::Dochazka::REST::Model::Schedule->load_by_sid( $dbix_conn, $sid );
-    is( $status->level, 'OK', 'delete_testing_schedule 1' );
+    is( $status->level, 'OK', 'delete_testing_schedule: load OK' );
     if ( $status->not_ok ) {
         diag( Dumper $status );
         BAIL_OUT(0);
     }
+
     my $sched = $status->payload;
     $status = $sched->delete( $faux_context );
-    is( $status->level, 'OK', 'delete_testing_schedule 2' );
+    is( $status->level, 'OK', 'delete_testing_schedule: delete OK' );
     if ( $status->not_ok ) {
         diag( Dumper $status );
         BAIL_OUT(0);
