@@ -51,11 +51,11 @@ App::Dochazka::REST::Util::Timestamp - date/time-related utilities
 
 =head1 VERSION
 
-Version 0.427
+Version 0.443
 
 =cut
 
-our $VERSION = '0.427';
+our $VERSION = '0.443';
 
 
 
@@ -89,8 +89,6 @@ This module provides the following exports:
 
 =item L<split_tsrange> (function)
 
-=item L<canonicalize_ts> (function)
-
 =item L<subtract_days> (function)
 
 =item L<tsrange_equal> (function)
@@ -101,7 +99,7 @@ This module provides the following exports:
 
 use Exporter qw( import );
 our @EXPORT_OK = qw( $today $today_ts $yesterday $yesterday_ts $tomorrow
-    $tomorrow_ts $current_year $current_month canonicalize_ts subtract_days 
+    $tomorrow_ts $current_year $current_month subtract_days 
     tsrange_equal );
 
 our $t = localtime;
@@ -142,28 +140,6 @@ sub split_tsrange {
 
 
 
-=head2 canonicalize_ts
-
-Given a string that might be a timestamp, "canonicalize" it by running it
-through the database in the SQL statement:
-
-    SELECT CAST( ? AS TIMESTAMP )
-
-=cut
-
-sub canonicalize_ts {
-    my ( $dbh, $ts ) = @_;
-
-    my ( $result ) = $dbh->selectrow_array( 
-        'SELECT CAST( ? AS timestamp)',
-        undef,
-        $ts,
-    ) if defined( $ts );
-
-    return $result;
-}
-
-
 =head2 subtract_days
 
 Given a timestamp and an integer n, subtract n days.
